@@ -1,5 +1,4 @@
-import html
-from typing import Any, List, Optional, Iterable, Set
+from typing import Any, Iterable, List, Optional, Set, Union
 
 
 def try_int(value: Any) -> Optional[int]:
@@ -10,9 +9,17 @@ def try_int(value: Any) -> Optional[int]:
         return None
 
 
+def try_float(value: Any) -> Optional[float]:
+    """ Convert any value to float or None (if impossible) """
+    try:
+        return float(value)
+    except (ValueError, TypeError):
+        return None
+
+
 def as_bool(value: Any) -> bool:
     """ Return True if value like true """
-    return value in (True, 1, '1', 'True', 'true', 't', b'1', b'True', b'true', b't')
+    return value in {True, 1, '1', 'True', 'true', 't', b'1', b'True', b'true', b't'}
 
 
 def to_string(val: Any) -> str:
@@ -26,17 +33,13 @@ def to_string(val: Any) -> str:
     return val
 
 
-def safe_text(text: str) -> str:
-    """ Escape tags from text """
-    return html.escape(text, True).replace('\xa0', ' ') if text else text
-
-
-def text_crop(text: str, length: int) -> str:
-    """ Crop text """
-    if len(text) > length:
-        return text[:length - 2] + ' …'
-
-    return text
+def to_bytes(value: Union[bytes, str, int], encoding: Optional[str] = None) -> bytes:
+    if isinstance(value, str):
+        return bytes(value, encoding or 'utf8')
+    elif isinstance(value, int):
+        return value.to_bytes((value.bit_length() + 7) // 8, 'big')
+    else:
+        return value
 
 
 def int_list(values: Iterable[Any]) -> List[int]:
